@@ -12,7 +12,7 @@ use File::Path qw( mkpath rmtree );
 use IPC::Run 'run';
 use Text::Diff ();
 
-our $VERSION = '1.09'; # VERSION
+our $VERSION = '1.10'; # VERSION
 
 sub init {
     die "Project already initialized\n" if ( -d '.dest' );
@@ -361,10 +361,10 @@ App::Dest - Deployment State Manager
 
 =head1 VERSION
 
-version 1.09
+version 1.10
 
-=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/App-Dest.svg)](https://travis-ci.org/gryphonshafer/App-Dest)
-[![Coverage Status](https://coveralls.io/repos/gryphonshafer/App-Dest/badge.png)](https://coveralls.io/r/gryphonshafer/App-Dest)
+=for markdown [![Build Status](https://travis-ci.org/gryphonshafer/dest.svg)](https://travis-ci.org/gryphonshafer/dest)
+[![Coverage Status](https://coveralls.io/repos/gryphonshafer/dest/badge.png)](https://coveralls.io/r/gryphonshafer/dest)
 
 =head1 SYNOPSIS
 
@@ -656,7 +656,7 @@ You can also look for additional information at:
 
 =item *
 
-L<GitHub|https://github.com/gryphonshafer/App-Dest>
+L<GitHub|https://github.com/gryphonshafer/dest>
 
 =item *
 
@@ -672,11 +672,11 @@ L<AnnoCPAN|http://annocpan.org/dist/App-Dest>
 
 =item *
 
-L<Travis CI|https://travis-ci.org/gryphonshafer/App-Dest>
+L<Travis CI|https://travis-ci.org/gryphonshafer/dest>
 
 =item *
 
-L<Coveralls|https://coveralls.io/r/gryphonshafer/App-Dest>
+L<Coveralls|https://coveralls.io/r/gryphonshafer/dest>
 
 =back
 
